pub struct HeaderMap(pub HeaderMap);Expand description
Header map extractor that provides access to HTTP request headers.
This extractor wraps a reference to the headers of a request, providing efficient access to header values without copying the underlying data. It can be used to inspect, validate, or extract information from HTTP headers.
Examples
use tako::extractors::header_map::HeaderMap;
use tako::types::Request;
async fn handler(HeaderMap(headers): HeaderMap<'_>) {
// Get authorization header
if let Some(auth) = headers.get("authorization") {
if let Ok(auth_str) = auth.to_str() {
println!("Authorization: {}", auth_str);
}
}
// Check content type
if let Some(content_type) = headers.get("content-type") {
println!("Content-Type: {:?}", content_type);
}
}Tuple Fields
0: HeaderMapTrait Implementations
Sourceimpl<'a> FromRequest<'a> for HeaderMap
impl<'a> FromRequest<'a> for HeaderMap
Sourceimpl<'a> FromRequestParts<'a> for HeaderMap
impl<'a> FromRequestParts<'a> for HeaderMap
Sourcetype Error = Infallible
type Error = Infallible
Error type returned when extraction fails.