pub struct ApiKeyAuth { /* private fields */ }Implementations
Sourceimpl ApiKeyAuth
impl ApiKeyAuth
Sourcepub fn new(key: impl Into<String>) -> ApiKeyAuth
pub fn new(key: impl Into<String>) -> ApiKeyAuth
Creates authentication middleware with a single static API key.
By default, the key is extracted from the X-API-Key header.
Sourcepub fn from_keys<I>(keys: I) -> ApiKeyAuth
pub fn from_keys<I>(keys: I) -> ApiKeyAuth
Creates authentication middleware with multiple static API keys.
Sourcepub fn with_verify<F>(f: F) -> ApiKeyAuth
pub fn with_verify<F>(f: F) -> ApiKeyAuth
Creates authentication middleware with a custom verification function.
Sourcepub fn from_keys_with_verify<I, F>(keys: I, f: F) -> ApiKeyAuthwhere
I: IntoIterator,
<I as IntoIterator>::Item: Into<String>,
F: Fn(&str) -> bool + Send + Sync + 'static,
pub fn from_keys_with_verify<I, F>(keys: I, f: F) -> ApiKeyAuthwhere
I: IntoIterator,
<I as IntoIterator>::Item: Into<String>,
F: Fn(&str) -> bool + Send + Sync + 'static,
Creates authentication with both static keys and custom verification.
Sourcepub fn location(self, location: ApiKeyLocation) -> ApiKeyAuth
pub fn location(self, location: ApiKeyLocation) -> ApiKeyAuth
Sets the location where the API key should be extracted from.
Sourcepub fn header_name(self, name: &'static str) -> ApiKeyAuth
pub fn header_name(self, name: &'static str) -> ApiKeyAuth
Sets a custom header name for API key extraction.
This is a convenience method equivalent to
.location(ApiKeyLocation::Header(name)).
Sourcepub fn query_param(self, name: &'static str) -> ApiKeyAuth
pub fn query_param(self, name: &'static str) -> ApiKeyAuth
Sets a query parameter name for API key extraction.
This is a convenience method equivalent to
.location(ApiKeyLocation::Query(name)).