Next

Struct Next 

pub struct Next {
    pub global_middlewares: Arc<Vec<Arc<dyn Fn(Request<TakoBody>, Next) -> Pin<Box<dyn Future<Output = Response<TakoBody>> + Send>> + Sync + Send>>>,
    pub route_middlewares: Arc<Vec<Arc<dyn Fn(Request<TakoBody>, Next) -> Pin<Box<dyn Future<Output = Response<TakoBody>> + Send>> + Sync + Send>>>,
    pub index: usize,
    pub endpoint: BoxHandler,
}
Represents the next step in the middleware execution chain.

Next is passed to middleware functions to allow them to continue the request processing chain. Calling next.run(req) will execute the remaining middleware and eventually the endpoint handler.

Fields

global_middlewares: Arc<Vec<Arc<dyn Fn(Request<TakoBody>, Next) -> Pin<Box<dyn Future<Output = Response<TakoBody>> + Send>> + Sync + Send>>>

Global middlewares to be executed before route-specific ones.

route_middlewares: Arc<Vec<Arc<dyn Fn(Request<TakoBody>, Next) -> Pin<Box<dyn Future<Output = Response<TakoBody>> + Send>> + Sync + Send>>>

Route-specific middlewares executed after global ones.

index: usize

Current position within the middleware chain.

endpoint: BoxHandler

Final endpoint handler to be called after all middlewares.

Implementations

Source

impl Next

pub async fn run(self, req: Request<TakoBody>) -> Response<TakoBody>

Executes the next middleware or endpoint in the chain.