pub struct UploadProgress { /* private fields */ }Expand description
Upload progress middleware configuration.
Examples
use tako::middleware::upload_progress::UploadProgress;
use tako::middleware::IntoMiddleware;
// Simple progress tracking (access via ProgressTracker in extensions)
let progress = UploadProgress::new();
// With progress callback
let progress = UploadProgress::new()
.on_progress(|state| {
if let Some(pct) = state.percent() {
println!("Upload: {pct}%");
}
})
.min_notify_interval_bytes(8192); // notify at most every 8KBImplementations
Sourceimpl UploadProgress
impl UploadProgress
Sourcepub fn new() -> UploadProgress
pub fn new() -> UploadProgress
Creates a new upload progress middleware.
Sourcepub fn on_progress<F>(self, f: F) -> UploadProgress
pub fn on_progress<F>(self, f: F) -> UploadProgress
Sets a callback that is called as bytes are received.
Sourcepub fn min_notify_interval_bytes(self, bytes: u64) -> UploadProgress
pub fn min_notify_interval_bytes(self, bytes: u64) -> UploadProgress
Sets the minimum byte interval between progress notifications.
This prevents the callback from being called too frequently for large uploads. Default is 0 (notify on every chunk).