#[non_exhaustive]pub struct Link {
pub operation_ref: String,
pub operation_id: String,
pub parameters: BTreeMap<String, Value>,
pub request_body: Option<Value>,
pub description: String,
pub server: Option<Server>,
pub extensions: Option<Extensions>,
}utoipa and (crate features utoipa or vespera) only.Expand description
Implements Open API Link Object for responses.
The Link represents possible design time link for a response. It does not guarantee
callers ability to invoke it but rather provides known relationship between responses and
other operations.
For computing links, and providing instructions to execute them, a runtime expression is used for accessing values in an operation and using them as parameters while invoking the linked operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operation_ref: StringA relative or absolute URI reference to an OAS operation. This field is
mutually exclusive of the operation_id field, and must point to an Operation
Object.
Relative operation_ref values may be used to locate an existing Operation
Object in the OpenAPI definition. See the rules for resolving Relative
References.
operation_id: StringThe name of an existing, resolvable OAS operation, as defined with a unique
operation_id.
This field is mutually exclusive of the operation_ref field.
parameters: BTreeMap<String, Value>A map representing parameters to pass to an operation as specified with operation_id
or identified by operation_ref. The key is parameter name to be used and value can
be any value supported by JSON or an expression e.g. $path.id
request_body: Option<Value>A literal value or an expression to be used as request body when operation is called.
description: StringDescription of the link. Value supports Markdown syntax.
server: Option<Server>A Server object to be used by the target operation.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Link
impl Link
Sourcepub fn builder() -> LinkBuilder
pub fn builder() -> LinkBuilder
Construct a new LinkBuilder.
This is effectively same as calling LinkBuilder::new