pub type ErrorHandler = Arc<dyn Fn(Response<TakoBody>) -> Response<TakoBody> + Sync + Send>;Expand description
Type alias for a global error handler function.
Called when a response has a server error status (5xx). Receives the original response and can transform it (e.g., to return JSON errors instead of plain text).
Aliased Type
pub struct ErrorHandler { /* private fields */ }