CompioWebSocket

Struct CompioWebSocket 

pub struct CompioWebSocket<S> { /* private fields */ }
Available on crate feature compio-ws only.
A WebSocket stream wrapper for compio that wraps tungstenite directly.

This type provides async WebSocket functionality by wrapping a tungstenite WebSocket with a SyncStream adapter.

Implementations

Source

impl<S> CompioWebSocket<S>
where S: AsyncRead + AsyncWrite,

pub fn from_raw_socket( stream: S, role: Role, config: Option<WebSocketConfig>, ) -> CompioWebSocket<S>

Creates a WebSocket stream from a raw socket without performing handshake.

This is used after the HTTP upgrade handshake has already been completed.

pub async fn send(&mut self, message: Message) -> Result<(), Error>

Sends a WebSocket message.

pub async fn read(&mut self) -> Result<Message, Error>

Reads the next WebSocket message.

pub async fn flush(&mut self) -> Result<(), Error>

Flushes pending messages.

pub async fn close( &mut self, close_frame: Option<CloseFrame>, ) -> Result<(), Error>

Closes the WebSocket connection.

pub fn get_ref(&self) -> &S

Returns a reference to the underlying stream.

pub fn get_mut(&mut self) -> &mut S

Returns a mutable reference to the underlying stream.