pub struct CompioWebSocket<S> { /* private fields */ }Available on crate feature
compio-ws only.Expand description
A WebSocket stream wrapper for compio that wraps tungstenite directly.
This type provides async WebSocket functionality by wrapping a tungstenite
WebSocket with a SyncStream adapter.
Implementations
Sourceimpl<S> CompioWebSocket<S>where
S: AsyncRead + AsyncWrite,
impl<S> CompioWebSocket<S>where
S: AsyncRead + AsyncWrite,
Sourcepub fn from_raw_socket(
stream: S,
role: Role,
config: Option<WebSocketConfig>,
) -> CompioWebSocket<S>
pub fn from_raw_socket( stream: S, role: Role, config: Option<WebSocketConfig>, ) -> CompioWebSocket<S>
Creates a WebSocket stream from a raw socket without performing handshake.
This is used after the HTTP upgrade handshake has already been completed.